summaryrefslogtreecommitdiffstats
path: root/src/fileparser.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/fileparser.h')
-rw-r--r--src/fileparser.h12
1 files changed, 3 insertions, 9 deletions
diff --git a/src/fileparser.h b/src/fileparser.h
index 3132f92..3245878 100644
--- a/src/fileparser.h
+++ b/src/fileparser.h
@@ -18,15 +18,11 @@
#include "parserintf.h"
-/** @brief General file parser */
-class FileParser : public ParserInterface
+/** @brief Generic code parser */
+class FileCodeParser : public CodeParserInterface
{
public:
- virtual ~FileParser() {}
- void startTranslationUnit(const char *) {}
- void finishTranslationUnit() {}
- void parseInput(const char *, const char *,const std::unique_ptr<Entry> &, bool, QStrList &) {}
- bool needsPreprocessing(const QCString &) const { return FALSE; }
+ virtual ~FileCodeParser() {}
void parseCode(CodeOutputInterface &codeOutIntf,
const char *scopeName,
const QCString &input,
@@ -43,8 +39,6 @@ class FileParser : public ParserInterface
bool collectXRefs=TRUE
);
void resetCodeParserState() {}
- void parsePrototype(const char *) {}
};
-
#endif